@@ -13,12 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 import proto  # type: ignore
 
 from google.cloud.datastream_v1.types import datastream_resources
-from google.protobuf import field_mask_pb2  # type: ignore
-from google.protobuf import timestamp_pb2  # type: ignore
-
 
 __protobuf__ = proto.module(
     package="google.cloud.datastream.v1",
@@ -108,16 +107,31 @@ class DiscoverConnectionProfileRequest(proto.Message):
             This field is a member of `oneof`_ ``data_object``.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     connection_profile = proto.Field(
         proto.MESSAGE,
         number=200,
         oneof="target",
         message=datastream_resources.ConnectionProfile,
     )
-    connection_profile_name = proto.Field(proto.STRING, number=201, oneof="target",)
-    full_hierarchy = proto.Field(proto.BOOL, number=3, oneof="hierarchy",)
-    hierarchy_depth = proto.Field(proto.INT32, number=4, oneof="hierarchy",)
+    connection_profile_name = proto.Field(
+        proto.STRING,
+        number=201,
+        oneof="target",
+    )
+    full_hierarchy = proto.Field(
+        proto.BOOL,
+        number=3,
+        oneof="hierarchy",
+    )
+    hierarchy_depth = proto.Field(
+        proto.INT32,
+        number=4,
+        oneof="hierarchy",
+    )
     oracle_rdbms = proto.Field(
         proto.MESSAGE,
         number=100,
@@ -183,9 +197,18 @@ class FetchStaticIpsRequest(proto.Message):
             call. will likely not be specified.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class FetchStaticIpsResponse(proto.Message):
@@ -204,8 +227,14 @@ class FetchStaticIpsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    static_ips = proto.RepeatedField(proto.STRING, number=1,)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    static_ips = proto.RepeatedField(
+        proto.STRING,
+        number=1,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class ListConnectionProfilesRequest(proto.Message):
@@ -234,11 +263,26 @@ class ListConnectionProfilesRequest(proto.Message):
             Order by fields for the result.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListConnectionProfilesResponse(proto.Message):
@@ -260,10 +304,18 @@ class ListConnectionProfilesResponse(proto.Message):
         return self
 
     connection_profiles = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=datastream_resources.ConnectionProfile,
+        proto.MESSAGE,
+        number=1,
+        message=datastream_resources.ConnectionProfile,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=3,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=3,)
 
 
 class GetConnectionProfileRequest(proto.Message):
@@ -275,7 +327,10 @@ class GetConnectionProfileRequest(proto.Message):
             resource to get.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateConnectionProfileRequest(proto.Message):
@@ -317,14 +372,31 @@ class CreateConnectionProfileRequest(proto.Message):
             without validating it.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    connection_profile_id = proto.Field(proto.STRING, number=2,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    connection_profile_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
     connection_profile = proto.Field(
-        proto.MESSAGE, number=3, message=datastream_resources.ConnectionProfile,
+        proto.MESSAGE,
+        number=3,
+        message=datastream_resources.ConnectionProfile,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    validate_only = proto.Field(
+        proto.BOOL,
+        number=5,
+    )
+    force = proto.Field(
+        proto.BOOL,
+        number=6,
     )
-    request_id = proto.Field(proto.STRING, number=4,)
-    validate_only = proto.Field(proto.BOOL, number=5,)
-    force = proto.Field(proto.BOOL, number=6,)
 
 
 class UpdateConnectionProfileRequest(proto.Message):
@@ -368,14 +440,27 @@ class UpdateConnectionProfileRequest(proto.Message):
     """
 
     update_mask = proto.Field(
-        proto.MESSAGE, number=1, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=1,
+        message=field_mask_pb2.FieldMask,
     )
     connection_profile = proto.Field(
-        proto.MESSAGE, number=2, message=datastream_resources.ConnectionProfile,
+        proto.MESSAGE,
+        number=2,
+        message=datastream_resources.ConnectionProfile,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    validate_only = proto.Field(
+        proto.BOOL,
+        number=4,
+    )
+    force = proto.Field(
+        proto.BOOL,
+        number=5,
     )
-    request_id = proto.Field(proto.STRING, number=3,)
-    validate_only = proto.Field(proto.BOOL, number=4,)
-    force = proto.Field(proto.BOOL, number=5,)
 
 
 class DeleteConnectionProfileRequest(proto.Message):
@@ -405,8 +490,14 @@ class DeleteConnectionProfileRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    request_id = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class ListStreamsRequest(proto.Message):
@@ -434,11 +525,26 @@ class ListStreamsRequest(proto.Message):
             Order by fields for the result.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListStreamsResponse(proto.Message):
@@ -460,10 +566,18 @@ class ListStreamsResponse(proto.Message):
         return self
 
     streams = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=datastream_resources.Stream,
+        proto.MESSAGE,
+        number=1,
+        message=datastream_resources.Stream,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=3,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=3,)
 
 
 class GetStreamRequest(proto.Message):
@@ -475,7 +589,10 @@ class GetStreamRequest(proto.Message):
             get.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateStreamRequest(proto.Message):
@@ -515,12 +632,31 @@ class CreateStreamRequest(proto.Message):
             validating it.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    stream_id = proto.Field(proto.STRING, number=2,)
-    stream = proto.Field(proto.MESSAGE, number=3, message=datastream_resources.Stream,)
-    request_id = proto.Field(proto.STRING, number=4,)
-    validate_only = proto.Field(proto.BOOL, number=5,)
-    force = proto.Field(proto.BOOL, number=6,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    stream_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    stream = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=datastream_resources.Stream,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    validate_only = proto.Field(
+        proto.BOOL,
+        number=5,
+    )
+    force = proto.Field(
+        proto.BOOL,
+        number=6,
+    )
 
 
 class UpdateStreamRequest(proto.Message):
@@ -564,12 +700,27 @@ class UpdateStreamRequest(proto.Message):
     """
 
     update_mask = proto.Field(
-        proto.MESSAGE, number=1, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=1,
+        message=field_mask_pb2.FieldMask,
+    )
+    stream = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=datastream_resources.Stream,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    validate_only = proto.Field(
+        proto.BOOL,
+        number=4,
+    )
+    force = proto.Field(
+        proto.BOOL,
+        number=5,
     )
-    stream = proto.Field(proto.MESSAGE, number=2, message=datastream_resources.Stream,)
-    request_id = proto.Field(proto.STRING, number=3,)
-    validate_only = proto.Field(proto.BOOL, number=4,)
-    force = proto.Field(proto.BOOL, number=5,)
 
 
 class DeleteStreamRequest(proto.Message):
@@ -599,8 +750,14 @@ class DeleteStreamRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    request_id = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class GetStreamObjectRequest(proto.Message):
@@ -612,7 +769,10 @@ class GetStreamObjectRequest(proto.Message):
             resource to get.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class LookupStreamObjectRequest(proto.Message):
@@ -628,9 +788,14 @@ class LookupStreamObjectRequest(proto.Message):
             maps to the stream object.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     source_object_identifier = proto.Field(
-        proto.MESSAGE, number=2, message=datastream_resources.SourceObjectIdentifier,
+        proto.MESSAGE,
+        number=2,
+        message=datastream_resources.SourceObjectIdentifier,
     )
 
 
@@ -644,7 +809,10 @@ class StartBackfillJobRequest(proto.Message):
             resource to start a backfill job for.
     """
 
-    object_ = proto.Field(proto.STRING, number=1,)
+    object_ = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class StartBackfillJobResponse(proto.Message):
@@ -658,7 +826,9 @@ class StartBackfillJobResponse(proto.Message):
     """
 
     object_ = proto.Field(
-        proto.MESSAGE, number=1, message=datastream_resources.StreamObject,
+        proto.MESSAGE,
+        number=1,
+        message=datastream_resources.StreamObject,
     )
 
 
@@ -672,7 +842,10 @@ class StopBackfillJobRequest(proto.Message):
             resource to stop the backfill job for.
     """
 
-    object_ = proto.Field(proto.STRING, number=1,)
+    object_ = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class StopBackfillJobResponse(proto.Message):
@@ -686,7 +859,9 @@ class StopBackfillJobResponse(proto.Message):
     """
 
     object_ = proto.Field(
-        proto.MESSAGE, number=1, message=datastream_resources.StreamObject,
+        proto.MESSAGE,
+        number=1,
+        message=datastream_resources.StreamObject,
     )
 
 
@@ -711,9 +886,18 @@ class ListStreamObjectsRequest(proto.Message):
             provided the page token.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ListStreamObjectsResponse(proto.Message):
@@ -732,9 +916,14 @@ class ListStreamObjectsResponse(proto.Message):
         return self
 
     stream_objects = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=datastream_resources.StreamObject,
+        proto.MESSAGE,
+        number=1,
+        message=datastream_resources.StreamObject,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class OperationMetadata(proto.Message):
@@ -770,15 +959,40 @@ class OperationMetadata(proto.Message):
             if there are any.
     """
 
-    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    target = proto.Field(proto.STRING, number=3,)
-    verb = proto.Field(proto.STRING, number=4,)
-    status_message = proto.Field(proto.STRING, number=5,)
-    requested_cancellation = proto.Field(proto.BOOL, number=6,)
-    api_version = proto.Field(proto.STRING, number=7,)
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    target = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    verb = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    status_message = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    requested_cancellation = proto.Field(
+        proto.BOOL,
+        number=6,
+    )
+    api_version = proto.Field(
+        proto.STRING,
+        number=7,
+    )
     validation_result = proto.Field(
-        proto.MESSAGE, number=8, message=datastream_resources.ValidationResult,
+        proto.MESSAGE,
+        number=8,
+        message=datastream_resources.ValidationResult,
     )
 
 
@@ -815,12 +1029,23 @@ class CreatePrivateConnectionRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    private_connection_id = proto.Field(proto.STRING, number=2,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    private_connection_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
     private_connection = proto.Field(
-        proto.MESSAGE, number=3, message=datastream_resources.PrivateConnection,
+        proto.MESSAGE,
+        number=3,
+        message=datastream_resources.PrivateConnection,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=4,
     )
-    request_id = proto.Field(proto.STRING, number=4,)
 
 
 class ListPrivateConnectionsRequest(proto.Message):
@@ -850,11 +1075,26 @@ class ListPrivateConnectionsRequest(proto.Message):
             Order by fields for the result.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListPrivateConnectionsResponse(proto.Message):
@@ -877,10 +1117,18 @@ class ListPrivateConnectionsResponse(proto.Message):
         return self
 
     private_connections = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=datastream_resources.PrivateConnection,
+        proto.MESSAGE,
+        number=1,
+        message=datastream_resources.PrivateConnection,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=3,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=3,)
 
 
 class DeletePrivateConnectionRequest(proto.Message):
@@ -914,9 +1162,18 @@ class DeletePrivateConnectionRequest(proto.Message):
             be deleted.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    request_id = proto.Field(proto.STRING, number=2,)
-    force = proto.Field(proto.BOOL, number=3,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    force = proto.Field(
+        proto.BOOL,
+        number=3,
+    )
 
 
 class GetPrivateConnectionRequest(proto.Message):
@@ -928,7 +1185,10 @@ class GetPrivateConnectionRequest(proto.Message):
             connectivity configuration to get.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateRouteRequest(proto.Message):
@@ -962,10 +1222,23 @@ class CreateRouteRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    route_id = proto.Field(proto.STRING, number=2,)
-    route = proto.Field(proto.MESSAGE, number=3, message=datastream_resources.Route,)
-    request_id = proto.Field(proto.STRING, number=4,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    route_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    route = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=datastream_resources.Route,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ListRoutesRequest(proto.Message):
@@ -994,11 +1267,26 @@ class ListRoutesRequest(proto.Message):
             Order by fields for the result.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListRoutesResponse(proto.Message):
@@ -1020,10 +1308,18 @@ class ListRoutesResponse(proto.Message):
         return self
 
     routes = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=datastream_resources.Route,
+        proto.MESSAGE,
+        number=1,
+        message=datastream_resources.Route,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=3,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=3,)
 
 
 class DeleteRouteRequest(proto.Message):
@@ -1053,8 +1349,14 @@ class DeleteRouteRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    request_id = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class GetRouteRequest(proto.Message):
@@ -1066,7 +1368,10 @@ class GetRouteRequest(proto.Message):
             get.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
