@@ -13,11 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
-
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.datastream.v1",
@@ -75,16 +73,35 @@ class OracleProfile(proto.Message):
             Required. Password for the Oracle connection.
         database_service (str):
             Required. Database for the Oracle connection.
-        connection_attributes (Sequence[google.cloud.datastream_v1.types.OracleProfile.ConnectionAttributesEntry]):
+        connection_attributes (Mapping[str, str]):
             Connection string attributes
     """
 
-    hostname = proto.Field(proto.STRING, number=1,)
-    port = proto.Field(proto.INT32, number=2,)
-    username = proto.Field(proto.STRING, number=3,)
-    password = proto.Field(proto.STRING, number=4,)
-    database_service = proto.Field(proto.STRING, number=5,)
-    connection_attributes = proto.MapField(proto.STRING, proto.STRING, number=6,)
+    hostname = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    port = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    username = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    password = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    database_service = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    connection_attributes = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=6,
+    )
 
 
 class MysqlProfile(proto.Message):
@@ -105,11 +122,27 @@ class MysqlProfile(proto.Message):
             SSL configuration for the MySQL connection.
     """
 
-    hostname = proto.Field(proto.STRING, number=1,)
-    port = proto.Field(proto.INT32, number=2,)
-    username = proto.Field(proto.STRING, number=3,)
-    password = proto.Field(proto.STRING, number=4,)
-    ssl_config = proto.Field(proto.MESSAGE, number=5, message="MysqlSslConfig",)
+    hostname = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    port = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    username = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    password = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    ssl_config = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message="MysqlSslConfig",
+    )
 
 
 class GcsProfile(proto.Message):
@@ -123,13 +156,18 @@ class GcsProfile(proto.Message):
             bucket.
     """
 
-    bucket = proto.Field(proto.STRING, number=1,)
-    root_path = proto.Field(proto.STRING, number=2,)
+    bucket = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    root_path = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class StaticServiceIpConnectivity(proto.Message):
-    r"""Static IP address connectivity.
-    """
+    r"""Static IP address connectivity."""
 
 
 class ForwardSshTunnelConnectivity(proto.Message):
@@ -159,11 +197,28 @@ class ForwardSshTunnelConnectivity(proto.Message):
             This field is a member of `oneof`_ ``authentication_method``.
     """
 
-    hostname = proto.Field(proto.STRING, number=1,)
-    username = proto.Field(proto.STRING, number=2,)
-    port = proto.Field(proto.INT32, number=3,)
-    password = proto.Field(proto.STRING, number=100, oneof="authentication_method",)
-    private_key = proto.Field(proto.STRING, number=101, oneof="authentication_method",)
+    hostname = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    username = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    port = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    password = proto.Field(
+        proto.STRING,
+        number=100,
+        oneof="authentication_method",
+    )
+    private_key = proto.Field(
+        proto.STRING,
+        number=101,
+        oneof="authentication_method",
+    )
 
 
 class VpcPeeringConfig(proto.Message):
@@ -180,8 +235,14 @@ class VpcPeeringConfig(proto.Message):
             /29)
     """
 
-    vpc = proto.Field(proto.STRING, number=1,)
-    subnet = proto.Field(proto.STRING, number=2,)
+    vpc = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    subnet = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class PrivateConnection(proto.Message):
@@ -195,7 +256,7 @@ class PrivateConnection(proto.Message):
             Output only. The create time of the resource.
         update_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The update time of the resource.
-        labels (Sequence[google.cloud.datastream_v1.types.PrivateConnection.LabelsEntry]):
+        labels (Mapping[str, str]):
             Labels.
         display_name (str):
             Required. Display name.
@@ -218,15 +279,43 @@ class PrivateConnection(proto.Message):
         DELETING = 4
         FAILED_TO_DELETE = 5
 
-    name = proto.Field(proto.STRING, number=1,)
-    create_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=4,)
-    display_name = proto.Field(proto.STRING, number=5,)
-    state = proto.Field(proto.ENUM, number=6, enum=State,)
-    error = proto.Field(proto.MESSAGE, number=7, message="Error",)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=4,
+    )
+    display_name = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=6,
+        enum=State,
+    )
+    error = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message="Error",
+    )
     vpc_peering_config = proto.Field(
-        proto.MESSAGE, number=100, message="VpcPeeringConfig",
+        proto.MESSAGE,
+        number=100,
+        message="VpcPeeringConfig",
     )
 
 
@@ -240,7 +329,10 @@ class PrivateConnectivity(proto.Message):
             ``projects/{project}/locations/{location}/privateConnections/{name}``
     """
 
-    private_connection = proto.Field(proto.STRING, number=1,)
+    private_connection = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class Route(proto.Message):
@@ -254,7 +346,7 @@ class Route(proto.Message):
             Output only. The create time of the resource.
         update_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The update time of the resource.
-        labels (Sequence[google.cloud.datastream_v1.types.Route.LabelsEntry]):
+        labels (Mapping[str, str]):
             Labels.
         display_name (str):
             Required. Display name.
@@ -264,13 +356,37 @@ class Route(proto.Message):
             Destination port for connection
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    create_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=4,)
-    display_name = proto.Field(proto.STRING, number=5,)
-    destination_address = proto.Field(proto.STRING, number=6,)
-    destination_port = proto.Field(proto.INT32, number=7,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=4,
+    )
+    display_name = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    destination_address = proto.Field(
+        proto.STRING,
+        number=6,
+    )
+    destination_port = proto.Field(
+        proto.INT32,
+        number=7,
+    )
 
 
 class MysqlSslConfig(proto.Message):
@@ -301,12 +417,30 @@ class MysqlSslConfig(proto.Message):
             set.
     """
 
-    client_key = proto.Field(proto.STRING, number=1,)
-    client_key_set = proto.Field(proto.BOOL, number=2,)
-    client_certificate = proto.Field(proto.STRING, number=3,)
-    client_certificate_set = proto.Field(proto.BOOL, number=4,)
-    ca_certificate = proto.Field(proto.STRING, number=5,)
-    ca_certificate_set = proto.Field(proto.BOOL, number=6,)
+    client_key = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    client_key_set = proto.Field(
+        proto.BOOL,
+        number=2,
+    )
+    client_certificate = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    client_certificate_set = proto.Field(
+        proto.BOOL,
+        number=4,
+    )
+    ca_certificate = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    ca_certificate_set = proto.Field(
+        proto.BOOL,
+        number=6,
+    )
 
 
 class ConnectionProfile(proto.Message):
@@ -327,7 +461,7 @@ class ConnectionProfile(proto.Message):
             Output only. The create time of the resource.
         update_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The update time of the resource.
-        labels (Sequence[google.cloud.datastream_v1.types.ConnectionProfile.LabelsEntry]):
+        labels (Mapping[str, str]):
             Labels.
         display_name (str):
             Required. Display name.
@@ -358,19 +492,46 @@ class ConnectionProfile(proto.Message):
             This field is a member of `oneof`_ ``connectivity``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    create_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=4,)
-    display_name = proto.Field(proto.STRING, number=5,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=4,
+    )
+    display_name = proto.Field(
+        proto.STRING,
+        number=5,
+    )
     oracle_profile = proto.Field(
-        proto.MESSAGE, number=100, oneof="profile", message="OracleProfile",
+        proto.MESSAGE,
+        number=100,
+        oneof="profile",
+        message="OracleProfile",
     )
     gcs_profile = proto.Field(
-        proto.MESSAGE, number=101, oneof="profile", message="GcsProfile",
+        proto.MESSAGE,
+        number=101,
+        oneof="profile",
+        message="GcsProfile",
     )
     mysql_profile = proto.Field(
-        proto.MESSAGE, number=102, oneof="profile", message="MysqlProfile",
+        proto.MESSAGE,
+        number=102,
+        oneof="profile",
+        message="MysqlProfile",
     )
     static_service_ip_connectivity = proto.Field(
         proto.MESSAGE,
@@ -385,7 +546,10 @@ class ConnectionProfile(proto.Message):
         message="ForwardSshTunnelConnectivity",
     )
     private_connectivity = proto.Field(
-        proto.MESSAGE, number=202, oneof="connectivity", message="PrivateConnectivity",
+        proto.MESSAGE,
+        number=202,
+        oneof="connectivity",
+        message="PrivateConnectivity",
     )
 
 
@@ -416,15 +580,42 @@ class OracleColumn(proto.Message):
             table.
     """
 
-    column = proto.Field(proto.STRING, number=1,)
-    data_type = proto.Field(proto.STRING, number=2,)
-    length = proto.Field(proto.INT32, number=3,)
-    precision = proto.Field(proto.INT32, number=4,)
-    scale = proto.Field(proto.INT32, number=5,)
-    encoding = proto.Field(proto.STRING, number=6,)
-    primary_key = proto.Field(proto.BOOL, number=7,)
-    nullable = proto.Field(proto.BOOL, number=8,)
-    ordinal_position = proto.Field(proto.INT32, number=9,)
+    column = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    data_type = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    length = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    precision = proto.Field(
+        proto.INT32,
+        number=4,
+    )
+    scale = proto.Field(
+        proto.INT32,
+        number=5,
+    )
+    encoding = proto.Field(
+        proto.STRING,
+        number=6,
+    )
+    primary_key = proto.Field(
+        proto.BOOL,
+        number=7,
+    )
+    nullable = proto.Field(
+        proto.BOOL,
+        number=8,
+    )
+    ordinal_position = proto.Field(
+        proto.INT32,
+        number=9,
+    )
 
 
 class OracleTable(proto.Message):
@@ -439,9 +630,14 @@ class OracleTable(proto.Message):
             lists, includes/excludes everything.
     """
 
-    table = proto.Field(proto.STRING, number=1,)
+    table = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     oracle_columns = proto.RepeatedField(
-        proto.MESSAGE, number=2, message="OracleColumn",
+        proto.MESSAGE,
+        number=2,
+        message="OracleColumn",
     )
 
 
@@ -455,8 +651,15 @@ class OracleSchema(proto.Message):
             Tables in the schema.
     """
 
-    schema = proto.Field(proto.STRING, number=1,)
-    oracle_tables = proto.RepeatedField(proto.MESSAGE, number=2, message="OracleTable",)
+    schema = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    oracle_tables = proto.RepeatedField(
+        proto.MESSAGE,
+        number=2,
+        message="OracleTable",
+    )
 
 
 class OracleRdbms(proto.Message):
@@ -469,7 +672,9 @@ class OracleRdbms(proto.Message):
     """
 
     oracle_schemas = proto.RepeatedField(
-        proto.MESSAGE, number=1, message="OracleSchema",
+        proto.MESSAGE,
+        number=1,
+        message="OracleSchema",
     )
 
 
@@ -483,8 +688,16 @@ class OracleSourceConfig(proto.Message):
             Oracle objects to exclude from the stream.
     """
 
-    include_objects = proto.Field(proto.MESSAGE, number=1, message="OracleRdbms",)
-    exclude_objects = proto.Field(proto.MESSAGE, number=2, message="OracleRdbms",)
+    include_objects = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="OracleRdbms",
+    )
+    exclude_objects = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="OracleRdbms",
+    )
 
 
 class MysqlColumn(proto.Message):
@@ -512,13 +725,34 @@ class MysqlColumn(proto.Message):
             table.
     """
 
-    column = proto.Field(proto.STRING, number=1,)
-    data_type = proto.Field(proto.STRING, number=2,)
-    length = proto.Field(proto.INT32, number=3,)
-    collation = proto.Field(proto.STRING, number=4,)
-    primary_key = proto.Field(proto.BOOL, number=5,)
-    nullable = proto.Field(proto.BOOL, number=6,)
-    ordinal_position = proto.Field(proto.INT32, number=7,)
+    column = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    data_type = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    length = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    collation = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    primary_key = proto.Field(
+        proto.BOOL,
+        number=5,
+    )
+    nullable = proto.Field(
+        proto.BOOL,
+        number=6,
+    )
+    ordinal_position = proto.Field(
+        proto.INT32,
+        number=7,
+    )
 
 
 class MysqlTable(proto.Message):
@@ -533,8 +767,15 @@ class MysqlTable(proto.Message):
             lists, includes/excludes everything.
     """
 
-    table = proto.Field(proto.STRING, number=1,)
-    mysql_columns = proto.RepeatedField(proto.MESSAGE, number=2, message="MysqlColumn",)
+    table = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    mysql_columns = proto.RepeatedField(
+        proto.MESSAGE,
+        number=2,
+        message="MysqlColumn",
+    )
 
 
 class MysqlDatabase(proto.Message):
@@ -547,8 +788,15 @@ class MysqlDatabase(proto.Message):
             Tables in the database.
     """
 
-    database = proto.Field(proto.STRING, number=1,)
-    mysql_tables = proto.RepeatedField(proto.MESSAGE, number=2, message="MysqlTable",)
+    database = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    mysql_tables = proto.RepeatedField(
+        proto.MESSAGE,
+        number=2,
+        message="MysqlTable",
+    )
 
 
 class MysqlRdbms(proto.Message):
@@ -560,7 +808,9 @@ class MysqlRdbms(proto.Message):
     """
 
     mysql_databases = proto.RepeatedField(
-        proto.MESSAGE, number=1, message="MysqlDatabase",
+        proto.MESSAGE,
+        number=1,
+        message="MysqlDatabase",
     )
 
 
@@ -574,8 +824,16 @@ class MysqlSourceConfig(proto.Message):
             MySQL objects to exclude from the stream.
     """
 
-    include_objects = proto.Field(proto.MESSAGE, number=1, message="MysqlRdbms",)
-    exclude_objects = proto.Field(proto.MESSAGE, number=2, message="MysqlRdbms",)
+    include_objects = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="MysqlRdbms",
+    )
+    exclude_objects = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="MysqlRdbms",
+    )
 
 
 class SourceConfig(proto.Message):
@@ -602,7 +860,10 @@ class SourceConfig(proto.Message):
             This field is a member of `oneof`_ ``source_stream_config``.
     """
 
-    source_connection_profile = proto.Field(proto.STRING, number=1,)
+    source_connection_profile = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     oracle_source_config = proto.Field(
         proto.MESSAGE,
         number=100,
@@ -618,8 +879,7 @@ class SourceConfig(proto.Message):
 
 
 class AvroFileFormat(proto.Message):
-    r"""AVRO file format configuration.
-    """
+    r"""AVRO file format configuration."""
 
 
 class JsonFileFormat(proto.Message):
@@ -644,8 +904,16 @@ class JsonFileFormat(proto.Message):
         NO_COMPRESSION = 1
         GZIP = 2
 
-    schema_file_format = proto.Field(proto.ENUM, number=1, enum=SchemaFileFormat,)
-    compression = proto.Field(proto.ENUM, number=2, enum=JsonCompression,)
+    schema_file_format = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=SchemaFileFormat,
+    )
+    compression = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=JsonCompression,
+    )
 
 
 class GcsDestinationConfig(proto.Message):
@@ -679,16 +947,30 @@ class GcsDestinationConfig(proto.Message):
             This field is a member of `oneof`_ ``file_format``.
     """
 
-    path = proto.Field(proto.STRING, number=1,)
-    file_rotation_mb = proto.Field(proto.INT32, number=2,)
+    path = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    file_rotation_mb = proto.Field(
+        proto.INT32,
+        number=2,
+    )
     file_rotation_interval = proto.Field(
-        proto.MESSAGE, number=3, message=duration_pb2.Duration,
+        proto.MESSAGE,
+        number=3,
+        message=duration_pb2.Duration,
     )
     avro_file_format = proto.Field(
-        proto.MESSAGE, number=100, oneof="file_format", message="AvroFileFormat",
+        proto.MESSAGE,
+        number=100,
+        oneof="file_format",
+        message="AvroFileFormat",
     )
     json_file_format = proto.Field(
-        proto.MESSAGE, number=101, oneof="file_format", message="JsonFileFormat",
+        proto.MESSAGE,
+        number=101,
+        oneof="file_format",
+        message="JsonFileFormat",
     )
 
 
@@ -708,7 +990,10 @@ class DestinationConfig(proto.Message):
             This field is a member of `oneof`_ ``destination_stream_config``.
     """
 
-    destination_connection_profile = proto.Field(proto.STRING, number=1,)
+    destination_connection_profile = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     gcs_destination_config = proto.Field(
         proto.MESSAGE,
         number=100,
@@ -736,7 +1021,7 @@ class Stream(proto.Message):
         update_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The last update time of the
             stream.
-        labels (Sequence[google.cloud.datastream_v1.types.Stream.LabelsEntry]):
+        labels (Mapping[str, str]):
             Labels.
         display_name (str):
             Required. Display name.
@@ -807,10 +1092,16 @@ class Stream(proto.Message):
         """
 
         oracle_excluded_objects = proto.Field(
-            proto.MESSAGE, number=1, oneof="excluded_objects", message="OracleRdbms",
+            proto.MESSAGE,
+            number=1,
+            oneof="excluded_objects",
+            message="OracleRdbms",
         )
         mysql_excluded_objects = proto.Field(
-            proto.MESSAGE, number=2, oneof="excluded_objects", message="MysqlRdbms",
+            proto.MESSAGE,
+            number=2,
+            oneof="excluded_objects",
+            message="MysqlRdbms",
         )
 
     class BackfillNoneStrategy(proto.Message):
@@ -819,16 +1110,44 @@ class Stream(proto.Message):
 
         """
 
-    name = proto.Field(proto.STRING, number=1,)
-    create_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=4,)
-    display_name = proto.Field(proto.STRING, number=5,)
-    source_config = proto.Field(proto.MESSAGE, number=6, message="SourceConfig",)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=4,
+    )
+    display_name = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    source_config = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message="SourceConfig",
+    )
     destination_config = proto.Field(
-        proto.MESSAGE, number=7, message="DestinationConfig",
+        proto.MESSAGE,
+        number=7,
+        message="DestinationConfig",
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=8,
+        enum=State,
     )
-    state = proto.Field(proto.ENUM, number=8, enum=State,)
     backfill_all = proto.Field(
         proto.MESSAGE,
         number=101,
@@ -841,9 +1160,15 @@ class Stream(proto.Message):
         oneof="backfill_strategy",
         message=BackfillNoneStrategy,
     )
-    errors = proto.RepeatedField(proto.MESSAGE, number=9, message="Error",)
+    errors = proto.RepeatedField(
+        proto.MESSAGE,
+        number=9,
+        message="Error",
+    )
     customer_managed_encryption_key = proto.Field(
-        proto.STRING, number=10, optional=True,
+        proto.STRING,
+        number=10,
+        optional=True,
     )
 
 
@@ -869,14 +1194,38 @@ class StreamObject(proto.Message):
             The object identifier in the data source.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    create_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    display_name = proto.Field(proto.STRING, number=5,)
-    errors = proto.RepeatedField(proto.MESSAGE, number=6, message="Error",)
-    backfill_job = proto.Field(proto.MESSAGE, number=7, message="BackfillJob",)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    display_name = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    errors = proto.RepeatedField(
+        proto.MESSAGE,
+        number=6,
+        message="Error",
+    )
+    backfill_job = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message="BackfillJob",
+    )
     source_object = proto.Field(
-        proto.MESSAGE, number=8, message="SourceObjectIdentifier",
+        proto.MESSAGE,
+        number=8,
+        message="SourceObjectIdentifier",
     )
 
 
@@ -911,8 +1260,14 @@ class SourceObjectIdentifier(proto.Message):
                 Required. The table name.
         """
 
-        schema = proto.Field(proto.STRING, number=1,)
-        table = proto.Field(proto.STRING, number=2,)
+        schema = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        table = proto.Field(
+            proto.STRING,
+            number=2,
+        )
 
     class MysqlObjectIdentifier(proto.Message):
         r"""Mysql data source object identifier.
@@ -924,8 +1279,14 @@ class SourceObjectIdentifier(proto.Message):
                 Required. The table name.
         """
 
-        database = proto.Field(proto.STRING, number=1,)
-        table = proto.Field(proto.STRING, number=2,)
+        database = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        table = proto.Field(
+            proto.STRING,
+            number=2,
+        )
 
     oracle_identifier = proto.Field(
         proto.MESSAGE,
@@ -975,15 +1336,31 @@ class BackfillJob(proto.Message):
         AUTOMATIC = 1
         MANUAL = 2
 
-    state = proto.Field(proto.ENUM, number=1, enum=State,)
-    trigger = proto.Field(proto.ENUM, number=2, enum=Trigger,)
+    state = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=State,
+    )
+    trigger = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=Trigger,
+    )
     last_start_time = proto.Field(
-        proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
     )
     last_end_time = proto.Field(
-        proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
+    )
+    errors = proto.RepeatedField(
+        proto.MESSAGE,
+        number=5,
+        message="Error",
     )
-    errors = proto.RepeatedField(proto.MESSAGE, number=5, message="Error",)
 
 
 class Error(proto.Message):
@@ -1002,15 +1379,32 @@ class Error(proto.Message):
             the error that occurred.
         error_time (google.protobuf.timestamp_pb2.Timestamp):
             The time when the error occurred.
-        details (Sequence[google.cloud.datastream_v1.types.Error.DetailsEntry]):
+        details (Mapping[str, str]):
             Additional information about the error.
     """
 
-    reason = proto.Field(proto.STRING, number=1,)
-    error_uuid = proto.Field(proto.STRING, number=2,)
-    message = proto.Field(proto.STRING, number=3,)
-    error_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
-    details = proto.MapField(proto.STRING, proto.STRING, number=5,)
+    reason = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    error_uuid = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    message = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    error_time = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
+    )
+    details = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=5,
+    )
 
 
 class ValidationResult(proto.Message):
@@ -1022,7 +1416,11 @@ class ValidationResult(proto.Message):
             as well as not executed validations).
     """
 
-    validations = proto.RepeatedField(proto.MESSAGE, number=1, message="Validation",)
+    validations = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Validation",
+    )
 
 
 class Validation(proto.Message):
@@ -1046,10 +1444,24 @@ class Validation(proto.Message):
         FAILED = 2
         PASSED = 3
 
-    description = proto.Field(proto.STRING, number=1,)
-    state = proto.Field(proto.ENUM, number=2, enum=State,)
-    message = proto.RepeatedField(proto.MESSAGE, number=3, message="ValidationMessage",)
-    code = proto.Field(proto.STRING, number=4,)
+    description = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=State,
+    )
+    message = proto.RepeatedField(
+        proto.MESSAGE,
+        number=3,
+        message="ValidationMessage",
+    )
+    code = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ValidationMessage(proto.Message):
@@ -1060,7 +1472,7 @@ class ValidationMessage(proto.Message):
             The result of the validation.
         level (google.cloud.datastream_v1.types.ValidationMessage.Level):
             Message severity level (warning or error).
-        metadata (Sequence[google.cloud.datastream_v1.types.ValidationMessage.MetadataEntry]):
+        metadata (Mapping[str, str]):
             Additional metadata related to the result.
         code (str):
             A custom code identifying this specific
@@ -1073,10 +1485,24 @@ class ValidationMessage(proto.Message):
         WARNING = 1
         ERROR = 2
 
-    message = proto.Field(proto.STRING, number=1,)
-    level = proto.Field(proto.ENUM, number=2, enum=Level,)
-    metadata = proto.MapField(proto.STRING, proto.STRING, number=3,)
-    code = proto.Field(proto.STRING, number=4,)
+    message = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    level = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=Level,
+    )
+    metadata = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=3,
+    )
+    code = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
