@@ -15,20 +15,18 @@
 #
 import abc
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
-import pkg_resources
 
-import google.auth  # type: ignore
 import google.api_core
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, operations_v1
 from google.api_core import retry as retries
-from google.api_core import operations_v1
+import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
-from google.oauth2 import service_account  # type: ignore
-
-from google.cloud.datastream_v1alpha1.types import datastream
-from google.cloud.datastream_v1alpha1.types import datastream_resources
 from google.longrunning import operations_pb2  # type: ignore
+from google.oauth2 import service_account  # type: ignore
+import pkg_resources
+
+from google.cloud.datastream_v1alpha1.types import datastream, datastream_resources
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
@@ -83,6 +81,7 @@ class DatastreamTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
+
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
             host += ":443"
@@ -154,25 +153,39 @@ class DatastreamTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.list_streams: gapic_v1.method.wrap_method(
-                self.list_streams, default_timeout=None, client_info=client_info,
+                self.list_streams,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.get_stream: gapic_v1.method.wrap_method(
-                self.get_stream, default_timeout=None, client_info=client_info,
+                self.get_stream,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.create_stream: gapic_v1.method.wrap_method(
-                self.create_stream, default_timeout=60.0, client_info=client_info,
+                self.create_stream,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
             self.update_stream: gapic_v1.method.wrap_method(
-                self.update_stream, default_timeout=60.0, client_info=client_info,
+                self.update_stream,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
             self.delete_stream: gapic_v1.method.wrap_method(
-                self.delete_stream, default_timeout=60.0, client_info=client_info,
+                self.delete_stream,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
             self.fetch_errors: gapic_v1.method.wrap_method(
-                self.fetch_errors, default_timeout=None, client_info=client_info,
+                self.fetch_errors,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.fetch_static_ips: gapic_v1.method.wrap_method(
-                self.fetch_static_ips, default_timeout=None, client_info=client_info,
+                self.fetch_static_ips,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.create_private_connection: gapic_v1.method.wrap_method(
                 self.create_private_connection,
@@ -195,25 +208,33 @@ class DatastreamTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.create_route: gapic_v1.method.wrap_method(
-                self.create_route, default_timeout=60.0, client_info=client_info,
+                self.create_route,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
             self.get_route: gapic_v1.method.wrap_method(
-                self.get_route, default_timeout=None, client_info=client_info,
+                self.get_route,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.list_routes: gapic_v1.method.wrap_method(
-                self.list_routes, default_timeout=None, client_info=client_info,
+                self.list_routes,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.delete_route: gapic_v1.method.wrap_method(
-                self.delete_route, default_timeout=60.0, client_info=client_info,
+                self.delete_route,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
         }
 
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -431,5 +452,9 @@ class DatastreamTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("DatastreamTransport",)
